lake (lake v0.2.6)
View SourceConnect to and use RabbitMQ Streams.
Summary
Functions
Convert a delivered osiris chunk into a list of messages.
Establish a connection.
Establish a connection.
Establish a connection.
Respond to a consumer_update request.
Create a new stream.
Set a subscription's credit asynchronously.
Declare a publisher.
Delete a stream.
Delete a publisher.
Retrieve stream metadata such as endpoints and replicas.
Retrieve all partitions of SuperStream.
Publish a message asynchronously.
Publish a message synchronously.
Query a publisher's stored offset from the stream.
Query a publisher's sequence.
Determine the partition for RoutingKey.
Stop a connection.
Store a publisher's offset to the stream.
Retrieve statistics for Stream.
Subscribe to a stream.
Establish a connection via TLS.
Establish a connection via TLS.
Establish a connection via TLS.
Unsubscribe from a stream.
Functions
Convert a delivered osiris chunk into a list of messages.
Establish a connection.
Establish a connection.
Establish a connection.
Options supports the options gen_tcp:connect/2 offers, and also the following:
* {exchange_command_versions, boolean()}: Enable exchanging command versions. Requires RabbitMQ 3.11. Defaults to true.
Respond to a consumer_update request.
Create a new stream.
Set a subscription's credit asynchronously.
Declare a publisher.
Delete a stream.
Delete a publisher.
Retrieve stream metadata such as endpoints and replicas.
Retrieve all partitions of SuperStream.
Publish a message asynchronously.
Publish a message synchronously.
Query a publisher's stored offset from the stream.
Query a publisher's sequence.
Determine the partition for RoutingKey.
Stop a connection.
Store a publisher's offset to the stream.
FIXME store_offset/4 is fire-and-forget; maybe the name should indicate that?
Retrieve statistics for Stream.
Subscribe to a stream.
Establish a connection via TLS.
See also: tls_connect/5, tls_connect/6.
Establish a connection via TLS.
See also: tls_connect/4, tls_connect/6.
Establish a connection via TLS.
Options supports the options ssl:connect/2 offers, and also the following:
* {exchange_command_versions, boolean()}: Enable exchanging command versions. Requires RabbitMQ 3.11. Defaults to true.
See also: tls_connect/4, tls_connect/5.
Unsubscribe from a stream.